@@ -101,7 +101,7 @@ validate_predictions <- function(predictions, n_obs = NULL) {
 #' Validate PIT
 #'
 #' Checks that `pit` is numeric, doesn't have any NAs, and is either a vector,
-#' or a 1-D array with values in [0,1].
+#' or a 1-D array with values in `[0,1]`.
 #'
 #' @param pit The 'pit' object from the user.
 #' @return Either throws an error or returns a numeric vector.
@@ -319,7 +319,7 @@ adjust_gamma <- function(N,
     abort("Value of 'prob' must be in (0,1).")
   }
   if (is.null(interpolate_adj)) {
-    if (K <= 200) {
+    if (K <= 200 || N < 100) {
       interpolate_adj <- FALSE
     } else {
       interpolate_adj <- TRUE
@@ -521,8 +521,8 @@ get_interpolation_values <- function(N, K, L, prob) {
 #' within the bounds until z1 and takes the value in x1 at z1.
 #' @param x1 Vector of scaled ECDF values at the left end of the interval, z1.
 #' @param x2 Vector of scaled ECDF values at the right end of the interval, z2.
-#' @param z1 Left evaluation point in [0,1]
-#' @param z2 Right evaluation point in [0,1] with z2 > z1.
+#' @param z1 Left evaluation point in `[0,1]`
+#' @param z2 Right evaluation point in `[0,1]` with z2 > z1.
 #' @param N Total number of values in the sample.
 #' @return A vector containing the probability to transitioning from the values
 #' in x1 to each of the values in x2 weighted by the probabilities in p_int.
