@@ -9,9 +9,9 @@
 #' @family MCMC
 #'
 #' @template args-hist
-#' @param size An optional value to override [ggplot2::geom_point()]'s
+#' @param size Optional values to override [ggplot2::geom_point()]'s
 #'   default size (for `mcmc_rhat()`, `mcmc_neff()`) or
-#'   [ggplot2::geom_line()]'s default size (for `mcmc_acf()`).
+#'   [ggplot2::geom_line()]'s default line width (for `mcmc_acf()`).
 #' @param ... Currently ignored.
 #'
 #' @template return-ggplot-or-data
@@ -133,21 +133,22 @@ mcmc_rhat <- function(rhat, ..., size = NULL) {
 
   graph <- ggplot(
     data = data,
-    mapping = aes_(
-      x = ~ value,
-      y = ~ parameter,
-      color = ~ rating,
-      fill = ~ rating)) +
+    mapping = aes(
+      x = .data$value,
+      y = .data$parameter,
+      color = .data$rating,
+      fill = .data$rating)) +
     geom_segment(
-      mapping = aes_(
-        yend = ~ parameter,
-        xend = ifelse(min(data$value) < 1, 1, -Inf)),
-      na.rm = TRUE) +
+      mapping = aes(
+        yend = .data$parameter,
+        xend = ifelse(min(.data$value) < 1, 1, -Inf)),
+      na.rm = TRUE,
+      show.legend = TRUE) +
       bayesplot_theme_get()
 
   if (min(data$value) < 1) {
     graph <- graph +
-      vline_at(1, color = "gray", size = 1)
+      vline_at(1, color = "gray", linewidth = 1)
   }
 
   brks <- set_rhat_breaks(data$value)
@@ -158,7 +159,7 @@ mcmc_rhat <- function(rhat, ..., size = NULL) {
       brks[-1],
       color = "gray",
       linetype = 2,
-      size = 0.25) +
+      linewidth = 0.25) +
     labs(y = NULL, x = expression(hat(R))) +
     scale_fill_diagnostic("rhat") +
     scale_color_diagnostic("rhat") +
@@ -171,20 +172,21 @@ mcmc_rhat <- function(rhat, ..., size = NULL) {
 
 #' @rdname MCMC-diagnostics
 #' @export
-mcmc_rhat_hist <- function(rhat, ..., binwidth = NULL, breaks = NULL) {
+mcmc_rhat_hist <- function(rhat, ..., binwidth = NULL, bins = NULL, breaks = NULL) {
   check_ignored_arguments(...)
   data <- mcmc_rhat_data(rhat)
 
   ggplot(
     data = data,
-    mapping = aes_(
-      x = ~ value,
-      color = ~ rating,
-      fill = ~ rating)) +
+    mapping = aes(
+      x = .data$value,
+      color = .data$rating,
+      fill = .data$rating)) +
     geom_histogram(
-      size = .25,
+      linewidth = 0.25,
       na.rm = TRUE,
       binwidth = binwidth,
+      bins = bins,
       breaks = breaks
     ) +
     scale_color_diagnostic("rhat") +
@@ -230,20 +232,21 @@ mcmc_neff <- function(ratio, ..., size = NULL) {
 
   ggplot(
     data,
-    mapping = aes_(
-      x = ~ value,
-      y = ~ parameter,
-      color = ~ rating,
-      fill = ~ rating)) +
+    mapping = aes(
+      x = .data$value,
+      y = .data$parameter,
+      color = .data$rating,
+      fill = .data$rating)) +
     geom_segment(
-      aes_(yend = ~ parameter, xend = -Inf),
-      na.rm = TRUE) +
+      aes(yend = .data$parameter, xend = -Inf),
+      na.rm = TRUE,
+      show.legend = TRUE) +
     diagnostic_points(size) +
     vline_at(
       c(0.1, 0.5, 1),
       color = "gray",
       linetype = 2,
-      size = 0.25) +
+      linewidth = 0.25) +
     labs(y = NULL, x = expression(N[eff]/N)) +
     scale_fill_diagnostic("neff") +
     scale_color_diagnostic("neff") +
@@ -261,20 +264,21 @@ mcmc_neff <- function(ratio, ..., size = NULL) {
 
 #' @rdname MCMC-diagnostics
 #' @export
-mcmc_neff_hist <- function(ratio, ..., binwidth = NULL, breaks = NULL) {
+mcmc_neff_hist <- function(ratio, ..., binwidth = NULL, bins = NULL, breaks = NULL) {
   check_ignored_arguments(...)
   data <- mcmc_neff_data(ratio)
 
   ggplot(
     data,
-    mapping = aes_(
-      x = ~ value,
-      color = ~ rating,
-      fill = ~ rating)) +
+    mapping = aes(
+      x = .data$value,
+      color = .data$rating,
+      fill = .data$rating)) +
     geom_histogram(
-      size = .25,
+      linewidth = 0.25,
       na.rm = TRUE,
       binwidth = binwidth,
+      bins = bins,
       breaks = breaks) +
     scale_color_diagnostic("neff") +
     scale_fill_diagnostic("neff") +
@@ -358,17 +362,19 @@ mcmc_acf_bar <-
 #'   `x <= breaks[1]`, `breaks[1] < x <= breaks[2]`, `x > breaks[2]`).
 #' @return A factor the same length as `x` with three levels.
 #' @noRd
-diagnostic_factor <- function(x, breaks, ...) {
+diagnostic_factor <- function(x, ...) {
   UseMethod("diagnostic_factor")
 }
 
-diagnostic_factor.rhat <- function(x, breaks = c(1.05, 1.1)) {
+#' @export
+diagnostic_factor.rhat <- function(x, ..., breaks = c(1.05, 1.1)) {
   cut(x, breaks = c(-Inf, breaks, Inf),
       labels = c("low", "ok", "high"),
       ordered_result = FALSE)
 }
 
-diagnostic_factor.neff_ratio <- function(x, breaks = c(0.1, 0.5)) {
+#' @export
+diagnostic_factor.neff_ratio <- function(x, ..., breaks = c(0.1, 0.5)) {
   cut(x, breaks = c(-Inf, breaks, Inf),
       labels = c("low", "ok", "high"),
       ordered_result = FALSE)
@@ -404,7 +410,7 @@ zero_pad_int <- function(xs) {
 }
 
 diagnostic_points <- function(size = NULL) {
-  args <- list(shape = 21, na.rm = TRUE)
+  args <- list(shape = 21, na.rm = TRUE, show.legend = TRUE)
   do.call("geom_point", c(args, size = size))
 }
 
@@ -450,7 +456,6 @@ diagnostic_colors <- function(diagnostic = c("rhat", "neff_ratio"),
   }
 
   color_labels <- diagnostic_color_labels[[diagnostic]]
-
   list(diagnostic = diagnostic,
        aesthetic = aesthetic,
        color_levels = color_levels,
@@ -517,38 +522,39 @@ drop_NAs_and_warn <- function(x) {
     plot_data <- acf_data(x = x, lags = lags)
 
     if (num_chains(x) > 1) {
-      facet_args$facets <- "Chain ~ Parameter"
+      facet_args$rows <- vars(.data$Chain)
+      facet_args$cols <- vars(.data$Parameter)
       facet_fun <- "facet_grid"
     } else { # 1 chain
       facet_args$facets <- "Parameter"
       facet_fun <- "facet_wrap"
     }
 
-    graph <- ggplot(plot_data, aes_(x = ~ Lag, y = ~ AC))  +
+    graph <- ggplot(plot_data, aes(x = .data$Lag, y = .data$AC))  +
       bayesplot_theme_get()
     if (style == "bar") {
       graph <- graph +
         geom_bar(
           position = "identity",
           stat = "identity",
-          size = 0.2,
+          linewidth = 0.2,
           fill = get_color("l"),
           color = get_color("lh"),
           width = 1
         ) +
-        hline_0(size = 0.25, color = get_color("dh"))
+        hline_0(linewidth = 0.25, color = get_color("dh"))
     } else {
       graph <- graph +
-        hline_0(size = 0.25, color = get_color("m")) +
+        hline_0(linewidth = 0.25, color = get_color("m")) +
         geom_segment(
-          aes_(xend = ~ Lag),
+          aes(xend = .data$Lag),
           yend = 0,
           color = get_color("l"),
-          size = 0.2
+          linewidth = 0.2
         ) +
         do.call(
           "geom_line",
-          args = c(list(color = get_color("d")), size = size)
+          args = c(list(color = get_color("d")), linewidth = size)
         )
     }
 
