@@ -11,9 +11,9 @@
 #' @template args-regex_pars
 #' @template args-transformations
 #' @param ... Currently ignored.
-#' @param size,alpha For `mcmc_scatter()`, passed to
+#' @param shape,size,alpha For `mcmc_scatter()`, passed to
 #'   [ggplot2::geom_point()] to control the appearance of the points.
-#' @param binwidth For `mcmc_hex()`, an optional numeric vector of
+#' @param bins,binwidth For `mcmc_hex()`, an optional numeric vector of
 #'   *length two* passed to [ggplot2::geom_hex()] to override the
 #'   default binwidth in both the vertical and horizontal directions.
 #'
@@ -43,7 +43,7 @@
 #'    and `np_style` arguments can be used to add additional information in
 #'    the plot (in this case the approximate location of divergences).
 #'    For more on why the scatter plot with divergences is a useful
-#'    diagnostic tool see [Gabry et al. (2019)](https://github.com/jgabry/bayes-vis-paper).
+#'    diagnostic tool see [Gabry et al. (2019)](https://github.com/jgabry/bayes-vis-paper#readme).
 #'   }
 #'   \item{`mcmc_hex()`}{
 #'    Hexagonal heatmap of 2-D bin counts. This plot is useful in cases where
@@ -129,6 +129,7 @@ mcmc_scatter <- function(x,
                          regex_pars = character(),
                          transformations = list(),
                          ...,
+                         shape = 21,
                          size = 2.5,
                          alpha = 0.8,
                          np = NULL,
@@ -139,6 +140,7 @@ mcmc_scatter <- function(x,
     pars = pars,
     regex_pars = regex_pars,
     transformations = transformations,
+    shape = shape,
     size = size,
     alpha = alpha,
     hex = FALSE,
@@ -156,6 +158,7 @@ mcmc_hex <- function(x,
                      regex_pars = character(),
                      transformations = list(),
                      ...,
+                     bins = 30,
                      binwidth = NULL) {
   suggested_package("scales")
   suggested_package("hexbin")
@@ -166,6 +169,7 @@ mcmc_hex <- function(x,
     regex_pars = regex_pars,
     transformations = transformations,
     hex = TRUE,
+    bins = bins,
     binwidth = binwidth,
     size = NULL,
     alpha = NULL
@@ -210,7 +214,7 @@ mcmc_hex <- function(x,
 #'   `alpha`.
 #' @param grid_args,save_gg_objects For `mcmc_pairs()`, arguments to pass to
 #'   [bayesplot_grid()]. For example, since `mcmc_pairs()` returns
-#'   more than a single ggplot object, using [ggtitle()] afterwards
+#'   more than a single ggplot object, using `ggtitle()` afterwards
 #'   will not work. But you you can still add a title to the plot using
 #'   `grid_args = list(top="My title")`.
 #'
@@ -351,7 +355,7 @@ mcmc_pairs <- function(x,
     divs <- dplyr::filter(np, UQ(param) == "divergent__") %>% pull(UQ(val))
     divergent__ <- matrix(divs, nrow = n_iter * n_chain, ncol = n_param)[, 1]
     if (!no_max_td) {
-      gt_max_td <- (dplyr::filter(np, UQ(param) == "treedepth__") %>% pull(UQ(val))) > max_treedepth
+      gt_max_td <- (dplyr::filter(np, UQ(param) == "treedepth__") %>% pull(UQ(val))) >= max_treedepth
       max_td_hit__ <- matrix(gt_max_td, nrow = n_iter * n_chain, ncol = n_param)[, 1]
     }
   }
@@ -403,7 +407,7 @@ mcmc_pairs <- function(x,
                              labels = c("NoDiv", "Div"))
         plots[[j]] <- plots[[j]] +
           geom_point(
-            aes_(color = divs_j_fac, size = divs_j_fac),
+            aes(color = divs_j_fac, size = divs_j_fac),
             shape = np_style$shape[["div"]],
             alpha = np_style$alpha[["div"]],
             na.rm = TRUE
@@ -414,7 +418,7 @@ mcmc_pairs <- function(x,
                                    labels = c("NoHit", "Hit"))
         plots[[j]] <- plots[[j]] +
           geom_point(
-            aes_(color = max_td_hit_j_fac, size = max_td_hit_j_fac),
+            aes(color = max_td_hit_j_fac, size = max_td_hit_j_fac),
             shape = np_style$shape[["td"]],
             alpha = np_style$alpha[["td"]],
             na.rm = TRUE
@@ -639,8 +643,10 @@ pairs_condition <- function(chains = NULL, draws = NULL, nuts = NULL) {
                           regex_pars = character(),
                           transformations = list(),
                           hex = FALSE,
+                          shape = 21,
                           size = 2.5,
                           alpha = 0.8,
+                          bins = 30,
                           binwidth = NULL,
                           np = NULL,
                           np_style = scatter_style_np()) {
@@ -675,13 +681,13 @@ pairs_condition <- function(chains = NULL, draws = NULL, nuts = NULL) {
     xydata <- dplyr::filter(xydata, UQ(divg) == 0)
   }
 
-  graph <- ggplot(data = xydata, aes_(x = ~ x, y = ~ y)) +
+  graph <- ggplot(data = xydata, aes(x = .data$x, y = .data$y)) +
     bayesplot_theme_get()
 
   if (!hex) { # scatterplot
     graph <- graph +
       geom_point(
-        shape = 21,
+        shape = shape,
         color = get_color("dh"),
         fill = get_color("d"),
         size = size,
@@ -701,7 +707,8 @@ pairs_condition <- function(chains = NULL, draws = NULL, nuts = NULL) {
   } else { # hex binning
     graph <- graph +
       geom_hex(
-        aes_(fill = ~ scales::rescale(..density..)),
+        aes(fill = scales::rescale(after_stat(density))),
+        bins = bins,
         binwidth = binwidth
       ) +
       scale_fill_gradientn(
@@ -903,7 +910,7 @@ format_nuts_points <- function(graph, np_args) {
                          c("NoDiv", "Div", "NoHit", "Hit"))
     ) +
     scale_size_manual(
-      values = set_names(c(0, rel(np_args$size[["div"]]), 0, rel(np_args$size[["td"]])),
+      values = set_names(c(NA, rel(np_args$size[["div"]]), NA, rel(np_args$size[["td"]])),
                          c("NoDiv", "Div", "NoHit", "Hit"))
     )
 }
