@@ -1,6 +1,3 @@
-library(bayesplot)
-context("PPC: loo")
-
 options(useFancyQuotes = FALSE)
 
 if (requireNamespace("rstanarm", quietly = TRUE) &&
@@ -213,6 +210,7 @@ test_that("ppc_loo_pit_overlay renders correctly", {
   skip_if_not_installed("vdiffr")
   skip_if_not_installed("loo")
   skip_on_r_oldrel()
+  skip_if(packageVersion("rstantools") <= "2.4.0")
 
   p_base <- suppressMessages(ppc_loo_pit_overlay(vdiff_loo_y, vdiff_loo_yrep, vdiff_loo_lw))
   vdiffr::expect_doppelganger("ppc_loo_pit_overlay (default)", p_base)
@@ -231,6 +229,7 @@ test_that("ppc_loo_pit_qq renders correctly", {
   skip_if_not_installed("vdiffr")
   skip_if_not_installed("loo")
   skip_on_r_oldrel()
+  skip_if(packageVersion("rstantools") <= "2.4.0")
 
   p_base <- ppc_loo_pit_qq(vdiff_loo_y, vdiff_loo_yrep, vdiff_loo_lw)
   vdiffr::expect_doppelganger("ppc_loo_pit_qq (default)", p_base)
@@ -305,6 +304,7 @@ test_that("ppc_loo_pit_ecdf renders correctly", {
   skip_if_not_installed("vdiffr")
   skip_if_not_installed("loo")
   skip_on_r_oldrel()
+  skip_if(packageVersion("rstantools") <= "2.4.0")
 
   psis_object <- suppressWarnings(loo::psis(-vdiff_loo_lw))
   p_base <- ppc_loo_pit_ecdf(
